@@ -9,7 +9,7 @@ from web_poet import ItemPage, handle_urls
 
 
 class POBase(ItemPage):
-    expected_overrides: Type[ItemPage]
+    expected_instead_of: Type[ItemPage]
     expected_patterns: Patterns
     expected_meta: Dict[str, Any]
 
@@ -18,8 +18,9 @@ class POLibSubOverriden(ItemPage):
     ...
 
 
-@handle_urls("sub_example.com", overrides=POLibSubOverriden)
+@handle_urls("sub.example", instead_of=POLibSubOverriden)
 class POLibSub(POBase):
-    expected_overrides = POLibSubOverriden
-    expected_patterns = Patterns(["sub_example.com"])
+    expected_instead_of = POLibSubOverriden
+    expected_patterns = Patterns(["sub.example"])
+    expected_to_return = None
     expected_meta = {}  # type: ignore
