@@ -10,6 +10,7 @@ class SelectableMixin(abc.ABC):
     Inherit from this mixin, implement ``._selector_input`` method,
     get ``.selector`` property and ``.xpath`` / ``.css`` methods.
     """
+
     __cached_selector = None
 
     @abc.abstractmethod
@@ -28,11 +29,11 @@ class SelectableMixin(abc.ABC):
         self.__cached_selector = sel
         return sel
 
-    def xpath(self, query, **kwargs):
+    def xpath(self, query, **kwargs) -> parsel.SelectorList:
         """A shortcut to ``.selector.xpath()``."""
         return self.selector.xpath(query, **kwargs)
 
-    def css(self, query):
+    def css(self, query) -> parsel.SelectorList:
         """A shortcut to ``.selector.css()``."""
         return self.selector.css(query)
 
@@ -40,12 +41,14 @@ class SelectableMixin(abc.ABC):
 # TODO: when dropping Python 3.7 support,
 # fix untyped ResponseShortcutsMixin.response using typing.Protocol
 
+
 class ResponseShortcutsMixin(SelectableMixin):
     """Common shortcut methods for working with HTML responses.
     This mixin could be used with Page Object base classes.
 
     It requires "response" attribute to be present.
     """
+
     _cached_base_url = None
 
     @property
@@ -64,7 +67,6 @@ class ResponseShortcutsMixin(SelectableMixin):
     @property
     def base_url(self) -> str:
         """Return the base url of the given response"""
-        # FIXME: move it to HttpResponse
         if self._cached_base_url is None:
             text = self.html[:4096]
             self._cached_base_url = get_base_url(text, self.url)
@@ -73,5 +75,4 @@ class ResponseShortcutsMixin(SelectableMixin):
     def urljoin(self, url: str) -> str:
         """Convert url to absolute, taking in account
         url and baseurl of the response"""
-        # FIXME: move it to HttpResponse
         return urljoin(self.base_url, url)
