@@ -19,7 +19,7 @@ logger = logging.getLogger(__name__)
 _StrMapping = Dict[str, str]
 _Headers = Union[_StrMapping, HttpRequestHeaders]
 _Body = Union[bytes, HttpRequestBody]
-_Status = Union[str, int]
+_StatusList = Union[str, int, List[Union[str, int]]]
 
 
 class HttpClient:
@@ -47,10 +47,12 @@ class HttpClient:
         response: HttpResponse,
         request: HttpRequest,
         *,
-        allow_status: List[_Status] = None,
+        allow_status: _StatusList = None,
     ) -> None:
         allow_status_normalized = list(map(str, as_list(allow_status)))
-        allow_all_status = any([True for s in allow_status_normalized if "*" == s.strip()])
+        allow_all_status = any(
+            [True for s in allow_status_normalized if "*" == s.strip()]
+        )
 
         if (
             allow_all_status
@@ -71,7 +73,7 @@ class HttpClient:
         method: str = "GET",
         headers: Optional[_Headers] = None,
         body: Optional[_Body] = None,
-        allow_status: List[_Status] = None,
+        allow_status: _StatusList = None,
     ) -> HttpResponse:
         """This is a shortcut for creating an :class:`~.HttpRequest` instance and
         executing that request.
@@ -106,7 +108,7 @@ class HttpClient:
         url: Union[str, _Url],
         *,
         headers: Optional[_Headers] = None,
-        allow_status: List[_Status] = None,
+        allow_status: _StatusList = None,
     ) -> HttpResponse:
         """Similar to :meth:`~.HttpClient.request` but peforming a ``GET``
         request.
@@ -124,7 +126,7 @@ class HttpClient:
         *,
         headers: Optional[_Headers] = None,
         body: Optional[_Body] = None,
-        allow_status: List[_Status] = None,
+        allow_status: _StatusList = None,
     ) -> HttpResponse:
         """Similar to :meth:`~.HttpClient.request` but performing a ``POST``
         request.
@@ -137,7 +139,9 @@ class HttpClient:
             allow_status=allow_status,
         )
 
-    async def execute(self, request: HttpRequest, *, allow_status: List[_Status] = None) -> HttpResponse:
+    async def execute(
+        self, request: HttpRequest, *, allow_status: _StatusList = None
+    ) -> HttpResponse:
         """Execute the specified :class:`~.HttpRequest` instance using the
         request implementation configured in the :class:`~.HttpClient`
         instance.
@@ -169,8 +173,8 @@ class HttpClient:
         self,
         *requests: HttpRequest,
         return_exceptions: bool = False,
-        allow_status: List[_Status] = None,
-    ) -> List[Union[HttpResponse, Exception]]:
+        allow_status: _StatusList = None,
+    ) -> List[Union[HttpResponse, HttpResponseError]]:
         """Similar to :meth:`~.HttpClient.execute` but accepts a collection of
         :class:`~.HttpRequest` instances that would be batch executed.
 
@@ -199,5 +203,7 @@ class HttpClient:
         """
 
         coroutines = [self.execute(r, allow_status=allow_status) for r in requests]
-        responses = await asyncio.gather(*coroutines, return_exceptions=return_exceptions)
+        responses = await asyncio.gather(
+            *coroutines, return_exceptions=return_exceptions
+        )
         return responses
